AssetEncoding

Enum AssetEncoding 

pub enum AssetEncoding {
    Identity,
    Brotli,
    Zstd,
    Gzip,
    Deflate,
}
The encoding of an asset.

Variants



Identity

The asset is not encoded.



Brotli

The asset is encoded with the Brotli algorithm.



Zstd

The asset is encoded with the Zstd algorithm.



Gzip

The asset is encoded with the Gzip algorithm.



Deflate

The asset is encoded with the Deflate algorithm.

Implementations

Source

impl AssetEncoding

pub fn default_config(self) -> (AssetEncoding, String)

Returns the default encoding and file extension for the encoding. The default encoding is the encoding that is used when the client does not specify an encoding in the Accept-Encoding header.

The default encoding and file extension are:

Examples
use ic_asset_certification::AssetEncoding;

let (encoding, extension) = AssetEncoding::Brotli.default_config();
assert_eq!(encoding, AssetEncoding::Brotli);
assert_eq!(extension, ".br");

let (encoding, extension) = AssetEncoding::Zstd.default_config();
assert_eq!(encoding, AssetEncoding::Zstd);
assert_eq!(extension, ".zst");

let (encoding, extension) = AssetEncoding::Gzip.default_config();
assert_eq!(encoding, AssetEncoding::Gzip);
assert_eq!(extension, ".gz");

let (encoding, extension) = AssetEncoding::Deflate.default_config();
assert_eq!(encoding, AssetEncoding::Deflate);
assert_eq!(extension, ".zz");

let (encoding, extension) = AssetEncoding::Identity.default_config();
assert_eq!(encoding, AssetEncoding::Identity);
assert_eq!(extension, "");
pub fn custom_config(self, extension: String) -> (AssetEncoding, String)

Returns an encoding with a custom file extension. This is useful when the default file extension assigned by default_config is not desired.

Examples
use ic_asset_certification::AssetEncoding;

let (encoding, extension) = AssetEncoding::Brotli.custom_config("brotli".to_string());

assert_eq!(encoding, AssetEncoding::Brotli);
assert_eq!(extension, "brotli");